"""
wx_combo_events.py - examine events from wx.ComboBox

User actions for output below:
    1) Select Choice2 from Combo pulldown
    2) Select Choice3 from Combo pulldown
    3) Position cursor after "i" and hit backspace
    4) hit backspace

On macOS 10.12.6
    wxPython version: 4.0.4 osx-cocoa (phoenix) wxWidgets 3.0.5
    Event ComboBox: Choice2
    Event ComboBox: Choice3
    Event Text: Choce3
    Event Text: Chce3

On Ubuntu 18.04
    wxPython version: 4.0.1 gtk3 (phoenix)
    Event Text: Choice2
    Event ComboBox: Choice2
    Event Text: Choice3
    Event ComboBox: Choice3
    Event Text: Choce3
    Event Text: Chce3

Brett Larson
30-Jan-2019
"""
import wx

class MyFrame(wx.Frame):

    def __init__(self):
        wx.Frame.__init__(self, None)

        choices = ["Choice1", "Choice2", "Choice3"]
        self.combo = wx.ComboBox(self, value=choices[0], choices=choices, name="Choice")

        self.Bind(wx.EVT_COMBOBOX, self.event_combo)
        self.Bind(wx.EVT_TEXT, self.event_text)

        sizer = wx.BoxSizer(wx.VERTICAL)
        sizer.Add(self.combo)
        self.SetSizer(sizer)

    def event_combo(self, event):
        print("Event ComboBox:", self.combo.GetValue())

    def event_text(self, event):
        print("Event Text:", self.combo.GetValue())

class MyApp(wx.App):

    def OnInit(self):
        frame = MyFrame()
        self.SetTopWindow(frame)
        frame.Show()
        return (True)

print("wxPython version:", wx.version())
app = MyApp(0)
app.MainLoop()
